aboutsummaryrefslogtreecommitdiff
path: root/src/simplewallet
diff options
context:
space:
mode:
authorRiccardo Spagni <ric@spagni.net>2016-09-03 22:03:44 +0200
committerRiccardo Spagni <ric@spagni.net>2016-09-03 22:03:44 +0200
commitdf63e0704aaed8ca4ce89f84586978c0b714ebf8 (patch)
tree46a59c67869cdbfcaaa1ec9d1aa904c97eb7987d /src/simplewallet
parentfix blockchain utilities readme (diff)
downloadmonero-df63e0704aaed8ca4ce89f84586978c0b714ebf8.tar.xz
fix remaining bitmonero and simplewallet bits
Diffstat (limited to 'src/simplewallet')
-rw-r--r--src/simplewallet/simplewallet.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/simplewallet/simplewallet.cpp b/src/simplewallet/simplewallet.cpp
index c1b0a2a95..421d1f53a 100644
--- a/src/simplewallet/simplewallet.cpp
+++ b/src/simplewallet/simplewallet.cpp
@@ -1598,7 +1598,7 @@ bool simple_wallet::new_wallet(const std::string &wallet_file, const std::string
tr("Your wallet has been generated!\n"
"To start synchronizing with the daemon, use \"refresh\" command.\n"
"Use \"help\" command to see the list of available commands.\n"
- "Always use \"exit\" command when closing simplewallet to save your\n"
+ "Always use \"exit\" command when closing monero-wallet-cli to save your\n"
"current session's state. Otherwise, you might need to synchronize \n"
"your wallet again (your wallet keys are NOT at risk in any case).\n")
;
@@ -3746,7 +3746,7 @@ int main(int argc, char* argv[])
return false;
}
// epee didn't find path to executable from argv[0], so use this default file name.
- log_file_name = "simplewallet.log";
+ log_file_name = "monero-wallet-cli.log";
// The full path will use cwd because epee also returned an empty default log folder.
}
default_log /= log_file_name;
@@ -3779,7 +3779,7 @@ int main(int argc, char* argv[])
if (command_line::get_arg(vm, command_line::arg_help))
{
success_msg_writer() << "Monero '" << MONERO_RELEASE_NAME << "' (v" << MONERO_VERSION_FULL << ")";
- success_msg_writer() << sw::tr("Usage:") << " simplewallet [--wallet-file=<file>|--generate-new-wallet=<file>] [--daemon-address=<host>:<port>] [<COMMAND>]";
+ success_msg_writer() << sw::tr("Usage:") << " monero-wallet-cli [--wallet-file=<file>|--generate-new-wallet=<file>] [--daemon-address=<host>:<port>] [<COMMAND>]";
success_msg_writer() << desc_all;
return false;
}
@@ -3798,8 +3798,8 @@ int main(int argc, char* argv[])
return 0;
// log_file_path
// default: < argv[0] directory >/simplewallet.log
// so if ran as "simplewallet" (no path), log file will be in cwd
//
// if log-file argument given:
// absolute path
@@ -3798,8 +3798,8 @@ int main(int argc, char* argv[])
return 0;
// log_file_path
- // default: < argv[0] directory >/simplewallet.log
- // so if ran as "simplewallet" (no path), log file will be in cwd
+ // default: < argv[0] directory >/monero-wallet-cli.log
+ // so if ran as "monero-wallet-cli" (no path), log file will be in cwd
//
// if log-file argument given: